@@ -1,8 +1,10 @@
 from .layers import *
 from .utils import *
+from .explainability import *
 
 from .FCN import *
 from .FCNPlus import *
+from .TCN import *
 from .InceptionTime import *
 from .InceptionTimePlus import *
 from .MLP import *
@@ -16,13 +18,15 @@ from .RNNPlus import *
 from .RNN_FCN import *
 from .RNN_FCNPlus import *
 from .ROCKET import *
+from .MINIROCKET import *
 from .TransformerModel import *
 from .TST import *
 from .TSTPlus import *
 from .XceptionTime import *
 from .XceptionTimePlus import *
+from .XCM import *
 from .XResNet1d import *
 from .XResNet1dPlus import *
 from fastai.vision.models.xresnet import *
 from .TabModel import *
-from .HybridDL import *
\ No newline at end of file
+from .MultiInputNet import *
\ No newline at end of file
